@@ -11,7 +11,10 @@ impl CollectParsers for ParsersImpl {
         let slice = parse_state.slice_with_len(length);
         ParseResult::successful(slice, length)
       }
-      ParseResult::Failure { get, is_committed } => ParseResult::failed(get, is_committed),
+      ParseResult::Failure {
+        error,
+        committed_status: is_committed,
+      } => ParseResult::failed(error, is_committed),
     })
   }
 }
