@@ -11,7 +11,10 @@ impl OffsetParsers for ParsersImpl {
         let ps = parse_state.add_offset(length);
         ParseResult::successful(ps.last_offset().unwrap_or(0), length)
       }
-      ParseResult::Failure { get, is_committed } => ParseResult::failed(get, is_committed),
+      ParseResult::Failure {
+        error,
+        committed_status: is_committed,
+      } => ParseResult::failed(error, is_committed),
     })
   }
 
@@ -23,7 +26,10 @@ impl OffsetParsers for ParsersImpl {
         let ps = parse_state.add_offset(length);
         ParseResult::successful(ps.next_offset(), length)
       }
-      ParseResult::Failure { get, is_committed } => ParseResult::failed(get, is_committed),
+      ParseResult::Failure {
+        error,
+        committed_status: is_committed,
+      } => ParseResult::failed(error, is_committed),
     })
   }
 }
