@@ -9,7 +9,7 @@ impl SkipParsers for ParsersImpl {
       if input.len() >= n {
         ParseResult::successful((), n)
       } else {
-        ParseResult::failed_with_un_commit(ParseError::of_in_complete())
+        ParseResult::failed_with_uncommitted(ParseError::of_in_complete())
       }
     })
   }
